/**
 * user table
 */
drop table if exists user;
create table user (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    user_name TEXT UNIQUE,
    password TEXT NOT NULL,
    user_role INTEGER,
    display_name TEXT,
    default_access TEXT DEFAULT 'allow',
    path_config TEXT,
    failure_count INTEGER DEFAULT 1,
    failure_date INTEGER,
    create_date INTEGER,
    update_date INTEGER,
    note TEXT
);

/**
 * page table
 */
drop table if exists page;
create table page (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    template_id INTEGER,
    page_path TEXT UNIQUE,
    page_type TEXT, -- 1=dir / 2=template / 3=file
    directory TEXT,
    file_name TEXT,
    extension TEXT,
    char_code TEXT,
    title TEXT,
    keywords TEXT,
    description TEXT,
    public_flag INTEGER DEFAULT 1,
    note TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER,
    update_date INTEGER
);
create index idx_page_page_path on page(page_path);

/**
 * template table
 */
drop table if exists template;
create table template (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    template_path TEXT UNIQUE,
    template_type TEXT, -- single / multi / archive / sub
    main_template TEXT,
    cond TEXT,
    output_method TEXT, -- static / dynamic
    char_code TEXT,
    page_no_seq INTEGER DEFAULT 1,
    metag_seq INTEGER DEFAULT 1,
    archive_repeat_id TEXT,
    archive_date_id TEXT, -- disuse column
    archive_start_month TEXT,
    archive_start_day TEXT,
    archive_prefix TEXT,
    archive_suffix TEXT,
    per_page TEXT,
    note TEXT,
    create_date INTEGER,
    update_date INTEGER
);

/**
 * metag table
 */
drop table if exists metag;
create table metag (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    repeat_id TEXT,
    repeat_no INTEGER,
    id TEXT,
    node_value TEXT,
    url TEXT,
    attr TEXT
);
create index idx_metag_page_id on metag(page_id);

/**
 * relations table
 */
drop table if exists relation;
create table relation (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    from_template INTEGER,
    ref_page INTEGER,
    ref_template INTEGER
);

/**
 * page draft table
 */
drop table if exists page_draft;
create table page_draft (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    file_name TEXT,
    title TEXT,
    keywords TEXT,
    description TEXT,
    note TEXT,
    comment TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);

/**
 * metag draft table
 */
drop table if exists metag_draft;
create table metag_draft (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    repeat_id TEXT,
    repeat_no INTEGER,
    id TEXT,
    node_value TEXT,
    url TEXT,
    attr TEXT
);
create index idx_metag_draft_page_id on metag_draft(page_id);

/**
 * license table
 */
drop table if exists license;
create table license (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    license_id TEXT,
    license_key TEXT,
    license_type TEXT,
    create_date INTEGER,
    update_date INTEGER
);

/**
 * MicroEngine CMS Information table
 */
drop table if exists meinfo;
create table meinfo (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    schema_version INTEGER DEFAULT 0,
    install_date INTEGER
);
INSERT INTO meinfo (_id, schema_version, install_date)
VALUES (1, 0, NULL);

/**
 * page revision table
 */
drop table if exists page_revision;
create table page_revision (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    title TEXT,
    keywords TEXT,
    description TEXT,
    note TEXT,
    comment TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);

/**
 * metag revision table
 */
drop table if exists metag_revision;
create table metag_revision (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    revision_id INTEGER,
    page_id INTEGER,
    repeat_id TEXT,
    repeat_no INTEGER,
    id TEXT,
    node_value TEXT,
    url TEXT,
    attr TEXT
);
create index idx_metag_revision_revision_id on metag_revision(page_id);

/**
 * content image table
 */
drop table if exists content_image;
create table content_image (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    file_name TEXT,
    file_path TEXT,
    page_id INTEGER,
    page_path TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);

/**
 * content file table
 */
drop table if exists content_file;
create table content_file (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    file_name TEXT,
    file_path TEXT,
    page_id INTEGER,
    page_path TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);

VACUUM;