<?php
/**
 * Content Image Logic
 * @package     Content
 * @copyright   Copyright (C) 2012 MicroEngine Inc.
 */
class Content_Image_Logic
{
    /** 画像一覧のアイテム数 */
    const PAGINATOR_SIZE = 50;

    /**
     * DAOオブジェクト
     * @var Content_Image_Dao
     */
    private $dao;

    /**
     * コンストラクタ
     */
    public function __construct()
    {
        $this->dao = new Content_Image_Dao();
    }

    /**
     * 画像登録処理
     * @param string $file_path
     * @param integer $page_id
     * @param string $page_path
     * @param integer $user_id
     * @param string $user_name
     * @return Content_Image $content_image
     */
    public function register($file_path, $page_id, $page_path, $user_id, $user_name)
    {
        $content_image = new Content_Image(basename($file_path), $file_path, $page_id, $page_path, $user_id, $user_name);
        $this->dao->insert($content_image);
        return $content_image;
    }

    /**
     * 画像一覧取得
     * @param string $path
     * @param string $position
     * @return array $rows, integer $total
     */
    public function get_image_list($path, $position)
    {
        $rows = $this->dao->get_image_list($path, self::PAGINATOR_SIZE + 1, $position * self::PAGINATOR_SIZE);
        $total = $this->dao->get_image_list_count($path);
        return array($rows, $total);
    }

    /**
     * 画像情報取得
     * @param string $image_id
     * @return Content_Image $image, array $image_files
     */
    public function get_image($image_id)
    {
        $image = $this->dao->select($image_id);
        $image_files = $this->get_related_images($image->file_path);

        return array($image, $image_files);
    }

    /**
     * 画像削除
     * @param Content_Image $image
     * @param array $image_files
     * @return boolean
     */
    public function delete_image(Content_Image $image, $image_files)
    {
        // DBからレコードを削除する
        $this->dao->delete($image);

        // 画像ファイルを削除する
        foreach ($image_files as $image_path) {
            $file_path = DOCUMENT_ROOT . $image_path;
            if (strlen(Me_Config::get('upload_root')) > 0 && strpos($image_path, UPLOAD_PATH) === 0) {
                $file_path = UPLOAD_ROOT . '/' . basename($file_path);
            }
            if (file_exists($file_path)) {
                unlink($file_path);
            }
        }
        // サムネイル画像を削除する
        $thumbs_image_path = UPLOAD_ROOT . Metag_Logic::THUMBNAIL_DIRECTORY . '/' . $image->file_name;
        if (file_exists($thumbs_image_path)) {
            unlink($thumbs_image_path);
        }

        return true;
    }

    /**
     * 関連画像取得
     * @param string $file_path
     * @return array $image_files
     */
    private function get_related_images($file_path)
    {
        $image_files = array();
        $default_file_name = $file_name = basename($file_path);
        $dir_path = pathinfo($file_path, PATHINFO_DIRNAME);
        $i = 1;
        while (true) {
            if ($i > 1) {
                $file_name = preg_replace('/\.[^\.]*$/', '-' . $i . '$0', $default_file_name);
            }
            $target_file_path = DOCUMENT_ROOT . $dir_path . '/' . $file_name;
            if (strlen(Me_Config::get('upload_root')) > 0 && strpos($file_path, UPLOAD_PATH) === 0) {
                $target_file_path = UPLOAD_ROOT . '/' . $file_name;
            }

            if (file_exists($target_file_path) && is_readable($target_file_path)) {
                $image_files[] = $dir_path . '/' . $file_name;
            } else {
                break;
            }
            $i++;
        }
        return $image_files;
    }
}