<?php
/**
 * File Logic
 * @package     File
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class File_Logic
{
    /**
     * コンストラクタ
     */
    public function __construct()
    {
    }

    /**
     * コード編集
     * @param stirng $page_id
     * @return File_Form $form
     */
    public function get_edit_file_form($page_id)
    {
        $page_logic = new Page_Logic();
        // DB情報取得
        $form = $page_logic->select($page_id, 'File_Form');
        // ファイルの内容を取得
        $this->get_template_file($form);

        // ソースコードの実態参照がtextareaでデコードされないように、'&'を変換して２重エンコード状態にする
        $form->file_contents = str_replace('&', '&amp;', $form->file_contents);

        return $form;
    }

    /**
     * ファイルの内容を取得
     * 文字コードはUTF-8に変換する
     * @param File_Form $form
     * @param string $char_code 文字コード
     */
    public function get_template_file(File_Form $form, $char_code = null)
    {
        // ファイルの内容取得
        $page_path = $form->page_path;
        if (Me_Util::should_convert_path()) {
            $page_path = mb_convert_encoding($page_path, 'SJIS-win', 'UTF-8');
        }
        $form->file_contents = Me_Util::get_file(SITE_ROOT . $page_path);

        if (!empty($char_code)) {
            $form->char_code = $char_code;
        } elseif (empty($form->char_code)) {
            // 文字コードが指定されていない場合は、mb関数で取得する。
            $form->char_code = mb_detect_encoding($form->file_contents, Me_Config::get_template('detect_order'));
        }

        // 文字コードがUTF-8以外の場合は変換する
        if (!empty($form->char_code) && $form->char_code != Template_Logic::CHAR_CODE) {
            $form->file_contents = mb_convert_encoding(
                    $form->file_contents, Template_Logic::CHAR_CODE, $form->char_code
            );
        }
    }

    /**
     * ファイル登録
     * @param File_Form $form
     * @return boolean
     */
    public function register_file(File_Form $form)
    {
        if (!$this->validation($form)) {
            return false;
        }

        // ファイル書き出し
        $this->write_file($form);

        // 文字コード・備考をアップデート
        $page_dao = new Page_Dao();
        $page = $page_dao->select($form->_id);
        $page->note = $form->note;
        $page->char_code = $form->char_code;
        $page_dao->update($page);

        return true;
    }

    /**
     * 入力値チェック
     * @param File_Form $form
     * @return boolean
     */
    public function validation(File_Form $form)
    {
        // エラーメッセージを初期化
        $form->errors = array();

        // テンプレートタイプ
        // 文字コード
        // 必須チェック
        if (strlen($form->char_code) < 1) {
            $form->errors['char_code'] = '文字コードを入力してください';
        }

        // 備考チェック
        if (50 < mb_strlen($form->note)) {
            $form->errors['note'] = '50文字以内で入力してください';
        }

        // エラー有無確認
        if (!empty($form->errors)) {
            $form->errors['MESSAGE'] = 'エラーが発生しました。';
            return false;
        }
        return true;
    }

    /**
     * ファイル書き出し
     * 書き出すパスにファイルが存在する場合は上書きする。
     * @param File_Form $form ファイルフォーム
     * @return boolean
     */
    private function write_file(File_Form $form)
    {
        // 書き出すファイルパス
        $file_path = SITE_ROOT . $form->page_path;

        // 文字コードがUTF-8以外の場合は、元の文字コードに戻す。
        if (!empty($form->char_code) && $form->char_code != Template_Logic::CHAR_CODE) {
            $form->file_contents = mb_convert_encoding(
                    $form->file_contents,
                    $form->char_code,
                    Template_Logic::CHAR_CODE
            );
        }

        // ファイル書き出し
        Me_Util::write_file($file_path, $form->file_contents);

        return true;
    }

    /**
     * ファイル削除
     * @param string $page_id
     * @return boolean
     */
    public function delete_file($page_id)
    {
        // DBから削除
        $page_dao = new Page_Dao();
        $page = $page_dao->select($page_id);
        $page_dao->delete($page);

        // ファイルを削除
        $file_path = SITE_ROOT . $page->page_path;
        if (file_exists($file_path)) {
            unlink($file_path);
        }

        return true;
    }
}