<?php
/**
 * Metag Draft Dao
 * @package     Metag
 * @copyright   Copyright (C) 2012 MicroEngine Inc.
 */
class Metag_Draft_Dao extends Metag_Dao
{
    /**
     * テーブル名
     * @var string
     */
    public $table_name = 'metag_draft';
    /**
     * Entityクラス名
     * @var stirng
     */
    public $class_name = 'Metag_Draft';

    /**
     * ページIDでレコードを取得
     * @param int $page_id
     * @param boolean $public_only
     * @return array $rows
     */
    public function select_by_page_id($page_id, $public_only = false)
    {
        if (empty($page_id)) {
            return array();
        }

        $query = <<< QUERY
select m._id, m.page_id, m.id, m.node_value, m.url, m.attr, m.repeat_id, m.repeat_no, p.page_path as ref_link_path
from metag_draft as m
left outer join page as p on (m.page_id = p._id)
where m.page_id = 1
and p.public_flag = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_id);
        if (!$public_only) {
            $sql->remove('and');
        }
        $rows = $sql->exec();
        foreach ($rows as &$row) {
            if (!empty($row['attr'])) {
                $row['attr'] = unserialize($row['attr']);
            }
            if (strlen(SITE_PATH) > 0 && !empty($row['ref_link_path'])) {
                $row['ref_link_path'] = SITE_PATH . $row['ref_link_path'];
            }
        }
        return $rows;
    }

    /**
     * ページID指定でレコードを削除
     * @param string $page_id
     * @return boolean
     */
    public function delete_by_page_id($page_id)
    {
        if (strlen($page_id) <= 0) {
            return false;
        }

        $query = <<< QUERY
delete from metag_draft
where page_id = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_id);
        $sql->exec();
        return true;
    }

    /**
     * テンプレートID指定でレコードを削除
     * @param string $template_id
     * @return boolean
     */
    public function delete_by_template_id($template_id)
    {
        if (strlen($template_id) <= 0) {
            return false;
        }

        $query = <<< QUERY
delete from metag_draft
where page_id in ( select _id from page where 
template_id = 1 )
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('template_id', 2, $template_id);
        $sql->exec();
        return true;
    }
}