<?php
/**
 * Metag Include
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_Include extends Metag
{
    /**
     * タグタイプ
     * @var string
     */
    public $node_type = 'include';
    /**
     * 表示名
     * @var string
     */
    public $display_name = 'インクルード (include)';
    /**
     * ブロック要素かどうか
     * @var boolean
     */
    public $is_block = false;
    /**
     * module name
     * @var string
     */
    public $module_name;
    /**
     * インクルードパス
     * @var string
     */
    public $path;
    /**
     * 属性リスト
     * @var array
     */
    public $attr_list = array(
        'id' => 'id',
        'module_name' => 'module_name',
        'path' => 'path',
        'ref_page_id' => 'ref_page_id',
    );

    /**
     * 編集view出力
     * @param array $row
     */
    public function edit_view($row)
    {
        // ファイル名のチェック
        if (!preg_match('|^[\w-./]+$|', $this->module_name)) {
            // a-zA-Z-9_-./ 以外の文字があれば読み込まない
            return;
        }
        $file_path = $this->get_include_path() . $this->module_name;
        if (file_exists($file_path)) {
            include($file_path);
        }
        return;
    }

    /**
     * 出力
     * @param $row array
     */
    public function output($row)
    {
        // ファイル名のチェック
        if (!preg_match('|^[\w-./]+$|', $this->module_name)) {
            // a-zA-Z-9_-./ 以外の文字があれば読み込まない
            return;
        }
        if ($this->output_method === Template_Logic::OUTPUT_DYNAMIC) {
            return '<?php $helper->include_module("' . $this->module_name . '", "' . $this->path . '") ;?>';
        } else {
            $file_path = $this->get_include_path() . $this->module_name;
            if (file_exists($file_path)) {
                return Me_Util::get_file($file_path);
            }
        }
    }

    /**
     * タグ編集
     */
    public function set_post_data()
    {
        $mapping = $this->attr_list;
        Me_Util::post_data_to_object($this, $mapping);
    }

    /**
     * インクルードパス取得
     * @return string
     */
    private function get_include_path()
    {
        $ret = '';
        if ($this->path === 'doc') {
            $ret = DOCUMENT_ROOT;
        } else if ($this->path === 'fs') {
            $ret = '';
        } else {
            $ret = DATA_ROOT . '/module/';
        }
        return $ret;
    }
}