<?php
/**
 * Metag Logic
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_Logic
{
    /** 編集画面で値がない場合の出力 */
    const BLANK = '&nbsp;&nbsp;';
    /** サムネイルディレクトリ */
    const THUMBNAIL_DIRECTORY = '/thumbs';
    /** サムネイル最大幅 */
    const THUMBNAIL_MAX_WIDTH = 120;
    /** サムネイル最大高さ */
    const THUMBNAIL_MAX_HEIGHT = 120;

    /**
     * DAOオブジェクト
     * @var Metag_Dao
     */
    private $dao;
    /**
     *
     * @var array
     */
    static private $type_list = array(
        'text' => 'テキスト',
        'textarea' => 'テキストエリア',
        'select' => 'プルダウンメニュー',
        'switch' => 'スイッチ',
        'list' => 'リスト',
        'rich' => 'リッチテキスト',
        'date' => '日付',
        'img' => '画像',
        'file' => 'ファイル',
        'source' => 'ソース',
        'attr' => 'アトリビュート',
        'repeat' => 'リピート',
        'delete' => 'デリート',
        'display' => 'ディスプレイ',
        'module' => 'モジュール',
        'include' => 'インクルード',
    );

    /**
     * コンストラクタ
     */
    public function __construct()
    {
        $this->dao = new Metag_Dao();
    }

    /**
     * reflect text
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_text($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect textarea
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_textarea($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect select
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_select($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect switch
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_switch($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect list
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_list($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 共通項目以外のpostされた値を取得
        $item_value = Me_Util::get_post_data('item_value');
        $item_url = Me_Util::get_post_data('item_url');
        $item_target = Me_Util::get_post_data('item_target');
        $node_value = array();
        for ($i = 0; $i < count($item_value); $i++) {
            // テキストが入力されている場合だけ取得
            if (strlen($item_value[$i]) > 0) {
                $node_value[$i]['value'] = $item_value[$i];
                $node_value[$i]['url'] = $item_url[$i];
                $node_value[$i]['target'] = $item_target[$i];
            }
        }

        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect rich
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_rich($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect date
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_date($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * reflect img
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_img($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        $row = $form->get_row($id, $metag->repeat_id, $repeat_no);

        // 共通項目以外のpostされた値を取得
        $unlink_file = Me_Util::get_post_data('unlink_file');
        $title = Me_Util::get_post_data('img_title');
        $alt = Me_Util::get_post_data('img_alt');

        if (!empty($unlink_file)) {
            // 旧画像処理
            $form->set_unlink_files($row['node_value']);

            // 値を空にする
            $row['node_value'] = '';
            $row['attr'] = array();
        } else if ($_FILES['node_value']['error'] !== UPLOAD_ERR_OK) {
            switch ($_FILES['node_value']['error']) {
                case UPLOAD_ERR_INI_SIZE:
                    throw new Me_Exception(603, ini_get('upload_max_filesize'));
                    break;
                case UPLOAD_ERR_NO_FILE:
                    // ファイルがない場合も属性の更新をするので、エラーにはしない。
                    break;
                default:
                    throw new Me_Exception(602);
                    break;
            }
        } else if (!empty($_FILES['node_value']['name'])) {
            // ファイル名・拡張子
            if (empty($metag->file_name)) {
                $save_file_name = time() . basename($_FILES['node_value']['tmp_name'], '.tmp');
                $pathinfo = pathinfo($_FILES['node_value']['name']);
                $extension = $pathinfo['extension'];
            } else {
                $pathinfo = pathinfo($metag->file_name);
                $extension = $pathinfo['extension'];
                $save_file_name = basename($metag->file_name, '.' . $extension);
            }

            // リサイズ処理
            $add_attr = array();
            $resize_list = explode(',', $metag->resize);
            $i = 1;
            foreach ($resize_list as $resize) {
                $resize = trim($resize);
                if (empty($resize) || strpos($resize, Metag_Img::RESIZE_SEPARATOR) === false) {
                    $max_width = Me_config::get('resize_width', 'image');
                    $max_height = Me_config::get('resize_height', 'image');
                } else {
                    list($max_width, $max_height) = explode(Metag_Img::RESIZE_SEPARATOR, $resize, 2);
                }

                $suffix = ($i === 1) ? '' : '-' . $i;

                // ファイル名
                $save_file_name_tmp = $save_file_name . $suffix . '.' . $extension;
                // ファイルパス
                $save_file_path = UPLOAD_ROOT . Page_Form::TEMPORARY_DIRECTORY . '/' . $save_file_name_tmp;

                // 画像保存
                list($new_width, $new_height) = Me_ImageUtil::create_image(
                        $_FILES['node_value']['tmp_name'], $save_file_path, $max_width, $max_height
                );
                $add_attr['width' . $suffix] = $new_width;
                $add_attr['height' . $suffix] = $new_height;
                $i++;
            }
            // サムネイル作成
            $save_file_path = UPLOAD_ROOT . self::THUMBNAIL_DIRECTORY . '/' . $save_file_name . '.' . $extension;
            Me_ImageUtil::create_image(
                $_FILES['node_value']['tmp_name'], $save_file_path, self::THUMBNAIL_MAX_WIDTH, self::THUMBNAIL_MAX_HEIGHT
            );

            // 旧画像処理
            $form->set_unlink_files($row['node_value']);

            // 要素に値をセット
            $row['node_value'] = UPLOAD_PATH . Page_Form::TEMPORARY_DIRECTORY . '/' . $save_file_name . '.' . $extension;
            if (is_array($row['attr'])) {
                $row['attr'] = array_merge($row['attr'], $add_attr);
            } else {
                $row['attr'] = $add_attr;
            }
        }
        if (strlen($metag->self_link) > 0 && strlen($row['node_value']) > 0) {
            $url = preg_replace('/\.[^\.]*$/', '-' . $metag->self_link . '$0', $row['node_value']);
        }
        $row['url'] = $url;
        $row['attr']['anchor'] = $anchor;
        $row['attr']['target'] = $target;
        $row['attr']['title'] = $title;
        $row['attr']['alt'] = $alt;
        $form->set_row($id, $row, $metag->repeat_id, $repeat_no);
    }

    /**
     * reflect file
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_file($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        $row = $form->get_row($id, $metag->repeat_id, $repeat_no);

        // 共通項目以外のpostされた値を取得
        $unlink_file = Me_Util::get_post_data('unlink_file');
        $link_text = Me_Util::get_post_data('link_text');

        if (!empty($unlink_file)) {
            // 削除がチェックされた
            $form->set_unlink_files($row['node_value']);

            // 値を空にする
            $row['node_value'] = '';
            $row['attr'] = array();
        } else if ($_FILES['node_value']['error'] !== UPLOAD_ERR_OK) {
            // ファイルアップロード時にエラーが発生
            switch ($_FILES['node_value']['error']) {
                case UPLOAD_ERR_INI_SIZE:
                    throw new Me_Exception(603, ini_get('upload_max_filesize'));
                    break;
                case UPLOAD_ERR_NO_FILE:
                    // ファイルがない場合も属性の更新をするので、エラーにはしない。
                    break;
                default:
                    throw new Me_Exception(602);
                    break;
            }
        } else if (!empty($_FILES['node_value']['name'])) {
            // 正常にファイルがアップロードされた
            // 保存ディレクトリ名・ファイル名・拡張子取得
            $save_dir_name = time() . basename($_FILES['node_value']['tmp_name'], '.tmp');
            $save_file_name = basename($_FILES['node_value']['name']);
            $pathinfo = pathinfo($_FILES['node_value']['name']);
            $extension = $pathinfo['extension'];

            // 旧ファイル処理
            $form->set_unlink_files($row['node_value']);

            // 要素に値をセット
            $row['node_value'] = UPLOAD_PATH . Page_Form::TEMPORARY_DIRECTORY . '/' . $save_dir_name . '/' . $save_file_name;

            // 保存ファイルパス
            $save_file_path = UPLOAD_ROOT . Page_Form::TEMPORARY_DIRECTORY . '/' . $save_dir_name . '/' . $save_file_name;

            // ファイル保存
            Me_Util::save_file($_FILES['node_value']['tmp_name'], $save_file_path);
            $row['attr']['filename'] = $save_file_name;
            $row['attr']['dirname'] = $save_dir_name;
            $row['attr']['extension'] = $extension;
            $row['attr']['size'] = $_FILES['node_value']['size'];
        }
        $row['attr']['target'] = $target;
        $row['attr']['link_text'] = $link_text;
        $form->set_row($id, $row, $metag->repeat_id, $repeat_no);
    }

    /**
     * reflect source
     * @param string $id
     * @param string $node_value
     * @param Page_Form $form
     * @param object $metag
     * @param string $repeat_no
     * @param string $url
     * @param string $target
     * @param string $anchor
     */
    public function reflect_source($id, $node_value, Page_Form $form, $metag, $repeat_no, $url, $target, $anchor)
    {
        // 要素に値をセット
        $form->set_node_value($id, $node_value, $metag->repeat_id, $repeat_no, $url, $target, $anchor);
    }

    /**
     * handling_repeat
     * @param string $command
     * @param string $repeat_id
     * @param string $repeat_no
     * @param Page_Form $form
     * @param array $options
     */
    public function handling_repeat($command, $repeat_id, $repeat_no, Page_Form $form, $options)
    {
        $old_repeat = $form->data[$repeat_id];
        $new_repeat = array();
        $new_repeat_no = max(array_keys($old_repeat)) + 1;
        // delete_before に 1 がセットされていたら、削除実行フラグを有効にする
        $do_delete = (boolean) $options['delete_before'];
        foreach ($old_repeat as $key => $rows) {
            // 前に追加
            if ($command === 'before' && $key == $repeat_no) {
                $new_repeat[$new_repeat_no] = array();
            }
            // 削除
            if ($command === 'delete') {
                // 削除実行フラグが有効か、リピートNoが一致したら削除する
                if ($do_delete || $key == $repeat_no) {
                    foreach ($rows as $row) {
                        $metag = $form->document->get_element_by_id($row['id']);
                        if ($metag->node_type === 'img') {
                            $form->set_unlink_files($row['node_value']);
                        }
                    }
                    // リピートNoが一致する場合は、delete_after がチェックされているかを確認する。
                    if ($key == $repeat_no) {
                        $do_delete = (boolean) $options['delete_after'];
                    }
                } else {
                    // 削除しない場合は追加
                    $new_repeat[$key] = $rows;
                }
            } else {
                // delete以外は追加
                $new_repeat[$key] = $rows;
            }
            // 複製
            if ($command === 'copy' && $key == $repeat_no) {
                $copied_rows = $rows;
                $copy_count = isset($options['copy_count']) ? $options['copy_count'] : 1;
                for ($i = 0; $i < $copy_count; $i++) {
                    foreach (array_keys($copied_rows) as $copied_key) {
                        unset($copied_rows[$copied_key]['_id']);
                        $copied_rows[$copied_key]['repeat_no'] = $new_repeat_no;
                        // インクリメント対応
                        if (isset($form->document->id_node_list[$copied_rows[$copied_key]['id']])) {
                            $copied_node = $form->document->id_node_list[$copied_rows[$copied_key]['id']];
                            if ($copied_node->node_type === 'date'
                                && strlen($copied_node->increment) > 0
                                && strlen($copied_rows[$copied_key]['node_value']) > 0
                            ) {
                                $copied_rows[$copied_key]['node_value'] = date('Y-m-d', strtotime($copied_rows[$copied_key]['node_value'] . ' ' . $copied_node->increment . ' day'));
                            }
                        }
                    }
                    $new_repeat[$new_repeat_no++] = $copied_rows;
                }
            }
            // 後に追加
            if ($command === 'after' && $key == $repeat_no) {
                $new_repeat[$new_repeat_no] = array();
            }
        }
        $form->data[$repeat_id] = $new_repeat;
    }

    /**
     * セレクタスイッチで次のオプションを選択する
     * @param string $id
     * @param string $repeat_id
     * @param string $repeat_no
     * @param Page_Form $form
     */
    public function next_option($id, $repeat_id, $repeat_no, Page_Form $form)
    {
        $metag = $form->document->get_element_by_id($id);
        $option_list = $metag->set_option_list();
        $option_list = array_values($option_list);

        // 該当行取得
        $row = $form->get_row($id, $repeat_id, $repeat_no);
        $node_value = $row['node_value'];
        $key = array_search($node_value, $option_list);
        if ($key == null) {
            $key = 0;
        }
        $next_key = ($key + 1) % count($option_list);
        $row['node_value'] = $option_list[$next_key];

        $form->set_row($id, $row, $repeat_id, $repeat_no);
    }

    /**
     * 入力値チェック
     * @param object $metag
     * @return boolean
     */
    public function validation($metag)
    {
        // エラーメッセージを初期化
        $metag->errors = array();

        // idを確認
        if (isset($metag->attr_list['id'])) {
            // 文字種チェック
            if (!preg_match('/^[A-Za-z]+[A-Za-z0-9_-]*$/', $metag->id)) {
                $metag->errors['id'] = 'IDは、先頭の一文字を英字にして、英字、数字、ハイフン( - )、アンダースコア( _ )のみで入力してください。';
            }
        }
        // ref_idを確認
        if (isset($metag->attr_list['ref_id']) && strlen($metag->ref_id)) {
            // 文字種チェック
            if (!preg_match('/^[A-Za-z_]+[A-Za-z0-9_-]*$/', $metag->ref_id)) {
                $metag->errors['ref_id'] = 'ref_idは、先頭の一文字を英字にして、英字、数字、ハイフン( - )、アンダースコア( _ )のみで入力してください。';
            }
        }

        // エラー有無確認
        if (!empty($metag->errors)) {
            $metag->errors['MESSAGE'] = 'エラーが発生しました。';
            return false;
        }
        return true;
    }

    /**
     * MEタグタイプの存在確認
     * @param string $type
     * @return boolean
     */
    static public function exist_type($type)
    {
        return isset(self::$type_list[$type]);
    }

    /**
     * MEタグ名取得
     * @param string $type
     * @return string
     */
    static public function get_display_name($type)
    {
        return self::$type_list[$type];
    }
}