<?php
/**
 * Template Dao
 * @package     Template
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Template_Dao extends Me_Dao
{
    /**
     * テーブル名
     * @var string
     */
    public $table_name = 'template';
    /**
     * Entityクラス名
     * @var stirng
     */
    public $class_name = 'Template';
    /**
     * カラム定義配列
     * @var array
     */
    public $column_list = array(
        '_id',
        'template_path',
        'template_type',
        'main_template',
        'cond',
        'output_method',
        'char_code',
        'page_no_seq',
        'metag_seq',
        'archive_repeat_id',
        'archive_start_month',
        'archive_start_day',
        'archive_prefix',
        'archive_suffix',
        'per_page',
        'note',
        'create_date',
        'update_date',
    );

    /**
     * コンストラクタ
     */
    public function __construct()
    {

    }

    /**
     * ページID指定でテンプレートオブジェクト取得
     * @param string $page_id
     * @param string $class_name
     * @return object $obj
     */
    public function select_by_page_id($page_id, $class_name = null)
    {
        $obj = null;
        if ($page_id === null || $page_id === '') {
            throw new Me_Exception(600);
        }

        $query = <<< QUERY
select * from template
where page_id = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_id);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $obj = $this->array_to_object($rows[0], $class_name);
        } else {
            if (is_null($class_name)) {
                $class_name = $this->class_name;
            }
            $obj = new $class_name;
        }
        return $obj;
    }

    /**
     * テンプレートID取得
     * @param string $template_path
     * @return string $template_id
     */
    public function select_id_by_template_path($template_path = '')
    {
        $template_id = null;
        $query = <<< QUERY
select _id
from template
where template_path = ''
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $template_path);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $template_id = $rows[0]['_id'];
        }
        return $template_id;
    }

    /**
     * サブテンプレートリスト取得
     * @param string $template_id
     * @return array $rows
     */
    public function select_sub_template_list($template_id)
    {
        $query = <<< QUERY
select _id, cond
from template
where main_template = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $template_id);
        $rows = $sql->exec();

        return $rows;
    }

    /**
     * テンプレートリスト取得
     * @param integer $limit
     * @param integer $offset
     * @return array $rows
     */
    public function get_template_list($limit = 100, $offset = 0)
    {

        $query = <<< QUERY
select p._id as page_id, t.template_path
from template as t
left join page as p on (t.template_path = p.page_path)
order by t.template_path asc
limit 100
offset 0 
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('limit', 1, $limit);
        $sql->bind('offset', 1, $offset);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * テンプレート数取得
     * @return integer
     */
    public function get_template_list_count()
    {
        $query = <<< QUERY
select count(*) as total
from template as t
left join page as p on (t.template_path = p.page_path)
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows[0]['total'];
    }

    /**
     * アーカイブテンプレートリスト取得
     * @return array $rows
     */
    public function get_archive_template_list()
    {
        $query = <<< QUERY
select t.template_path, t.archive_prefix, t.archive_suffix 
from template as t
where t.template_type = 'archive'
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * 全テンプレート取得
     * @return array $rows
     */
    public function select_all_template()
    {
        $query = <<< QUERY
select _id
from template
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows;
    }
}