<!DOCTYPE html>
<html lang="ja">
<head>
<link rel="stylesheet" href="../../app/assets/vendor/codemirror/lib/codemirror.css?v=<?php h::p(SCRIPT_VERSION) ?>">
<link rel="stylesheet" href="../../app/assets/vendor/codemirror/addon/dialog/dialog.css?v=<?php h::p(SCRIPT_VERSION) ?>">
<?php h::render('/Common/head.php') ?>
<title><?php h::p($page_title) ?> - MicroEngine CMS</title>
<script src="../../app/assets/js/require.js?v=<?php h::p(SCRIPT_VERSION) ?>"></script>
<script src="../../app/assets/js/me.template.js?v=<?php h::p(SCRIPT_VERSION) ?>"></script>
<script>
$(document).ready(function(){
    me.form.init();

    require([
        '../../app/assets/vendor/codemirror/lib/codemirror',
        '../../app/assets/vendor/codemirror/mode/htmlmixed/htmlmixed',
        '../../app/assets/vendor/codemirror/addon/dialog/dialog',
        '../../app/assets/vendor/codemirror/addon/search/search',
        '../../app/assets/vendor/codemirror/addon/search/searchcursor',
        '../../app/assets/vendor/codemirror/addon/search/jump-to-line'
    ], function(CodeMirror) {
        me.codeMirror = CodeMirror.fromTextArea(document.getElementById('source_code'), {
            mode: 'htmlmixed',
            lineNumbers: true,
            extraKeys: {'Alt-F': 'findPersistent'},
            cursorScrollMargin: 50,
            indentUnit: 4
        });
        if ($('#error_message').length > 0) {
            me.template.openSetting();
        } else {
            me.template.closeSetting();
        }
        me.template.changeTemplateType();
        me.resize.resizeCodeMirror();
        $(window).bind('resize', function(){
            me.resize.resizeCodeMirror();
            me.resize.resizeBox('preview_iframe');
        });
        $(document).on('click', '.search_btn', function (event) {
            me.template.search(this, event);
            return false;
        });
        $(document).on('keydown', '#query', function (event) {
            return me.template.queryKeydown(this, event);
        });
    });
});
</script>
</head>
<body>
<?php h::error($form->errors["MESSAGE"]) ?>
<div class="navbar">
<div class="navbar-inner header">
<span class="brand"><?php h::p($page_title) ?></span>
<ul class="nav">
<li>
<button id="open_template_setting" type="button" class="btn btn-small" onclick="me.template.openSetting();"><i class="icon-chevron-down"></i> 設定を開く</button>
<button id="close_template_setting" type="button" class="btn btn-small hide" onclick="me.template.closeSetting();"><i class="icon-chevron-up"></i> 設定を閉じる</button>
</li>
</ul>
<ul class="nav pull-right">
<li><a href="<?php h::p(MANUAL_BASE_URL) ?>template_edit.html" target="_blank"><i class="icon-question-sign"></i> ヘルプ</a></li>
</ul>
</div>
</div>
<form method="POST" name="template_form" id="template_form" class="form-inline" action="../Template/post" onsubmit="me.form.noUnload();">

<table id="setting_table" class="table setting_table">
<tr>
<th class="span3">テンプレートパス</th>
<td colspan="3"><?php h::p($form->template_path) ?></td>
</tr>
<tr class="template_setting">
<th>テンプレートタイプ</th>
<td colspan="3">
<label class="radio"><input type="radio" id="template_type_single" name="template_type" value="single" <?php h::radio($form->template_type, 'single') ?> onclick="me.template.changeTemplateType();">シングルタイプ&nbsp;</label>
<label class="radio"><input type="radio" id="template_type_multi" name="template_type" value="multi" <?php h::radio($form->template_type, 'multi') ?> onclick="me.template.changeTemplateType();">マルチタイプ&nbsp;</label>
<label class="radio"><input type="radio" id="template_type_pagination" name="template_type" value="pagination" <?php h::radio($form->template_type, 'pagination') ?> onclick="me.template.changeTemplateType();">ページネーションタイプ&nbsp;</label>
<label class="radio"><input type="radio" id="template_type_archive" name="template_type" value="archive" <?php h::radio($form->template_type, 'archive') ?> onclick="me.template.changeTemplateType();">アーカイブタイプ&nbsp;</label>
<label class="radio"><input type="radio" id="template_type_sub" name="template_type" value="sub" <?php h::radio($form->template_type, 'sub') ?> onclick="me.template.changeTemplateType();">サブタイプ&nbsp;</label>
<?php h::error( $form->errors["template_type"]) ?>
</td>
</tr>

<tr class="template_setting pagination_template_setting archive_template_setting">
<th>対象リピートID</th>
<td colspan="3">
<input type="text" id="archive_repeat_id" name="archive_repeat_id" class="input-medium" maxlength="50" value="<?php h::p( $form->archive_repeat_id) ?>">
<?php h::error( $form->errors["archive_repeat_id"]) ?>
</td>
</tr>
<tr class="template_setting archive_template_setting">
<th>アーカイブ開始月日</th>
<td colspan="3">
<select id="archive_start_month" name="archive_start_month" class="input-mini">
<option value="">--</option>
<option value="01" <?php h::select($form->archive_start_month, '01') ?>>1</option>
<option value="02" <?php h::select($form->archive_start_month, '02') ?>>2</option>
<option value="03" <?php h::select($form->archive_start_month, '03') ?>>3</option>
<option value="04" <?php h::select($form->archive_start_month, '04') ?>>4</option>
<option value="05" <?php h::select($form->archive_start_month, '05') ?>>5</option>
<option value="06" <?php h::select($form->archive_start_month, '06') ?>>6</option>
<option value="07" <?php h::select($form->archive_start_month, '07') ?>>7</option>
<option value="08" <?php h::select($form->archive_start_month, '08') ?>>8</option>
<option value="09" <?php h::select($form->archive_start_month, '09') ?>>9</option>
<option value="10" <?php h::select($form->archive_start_month, '10') ?>>10</option>
<option value="11" <?php h::select($form->archive_start_month, '11') ?>>11</option>
<option value="12" <?php h::select($form->archive_start_month, '12') ?>>12</option>
</select>
<span>月</span>
<select id="archive_start_day" name="archive_start_day" class="input-mini">
<option value="">--</option>
<option value="01" <?php h::select($form->archive_start_day, '01') ?>>1</option>
<option value="02" <?php h::select($form->archive_start_day, '02') ?>>2</option>
<option value="03" <?php h::select($form->archive_start_day, '03') ?>>3</option>
<option value="04" <?php h::select($form->archive_start_day, '04') ?>>4</option>
<option value="05" <?php h::select($form->archive_start_day, '05') ?>>5</option>
<option value="06" <?php h::select($form->archive_start_day, '06') ?>>6</option>
<option value="07" <?php h::select($form->archive_start_day, '07') ?>>7</option>
<option value="08" <?php h::select($form->archive_start_day, '08') ?>>8</option>
<option value="09" <?php h::select($form->archive_start_day, '09') ?>>9</option>
<option value="10" <?php h::select($form->archive_start_day, '10') ?>>10</option>
<option value="11" <?php h::select($form->archive_start_day, '11') ?>>11</option>
<option value="12" <?php h::select($form->archive_start_day, '12') ?>>12</option>
<option value="13" <?php h::select($form->archive_start_day, '13') ?>>13</option>
<option value="14" <?php h::select($form->archive_start_day, '14') ?>>14</option>
<option value="15" <?php h::select($form->archive_start_day, '15') ?>>15</option>
<option value="16" <?php h::select($form->archive_start_day, '16') ?>>16</option>
<option value="17" <?php h::select($form->archive_start_day, '17') ?>>17</option>
<option value="18" <?php h::select($form->archive_start_day, '18') ?>>18</option>
<option value="19" <?php h::select($form->archive_start_day, '19') ?>>19</option>
<option value="20" <?php h::select($form->archive_start_day, '20') ?>>20</option>
<option value="21" <?php h::select($form->archive_start_day, '21') ?>>21</option>
<option value="22" <?php h::select($form->archive_start_day, '22') ?>>22</option>
<option value="23" <?php h::select($form->archive_start_day, '23') ?>>23</option>
<option value="24" <?php h::select($form->archive_start_day, '24') ?>>24</option>
<option value="25" <?php h::select($form->archive_start_day, '25') ?>>25</option>
<option value="26" <?php h::select($form->archive_start_day, '26') ?>>26</option>
<option value="27" <?php h::select($form->archive_start_day, '27') ?>>27</option>
<option value="28" <?php h::select($form->archive_start_day, '28') ?>>28</option>
<option value="29" <?php h::select($form->archive_start_day, '29') ?>>29</option>
<option value="30" <?php h::select($form->archive_start_day, '30') ?>>30</option>
<option value="31" <?php h::select($form->archive_start_day, '31') ?>>31</option>
</select>
<span>日</span><br>
<?php h::error( $form->errors["archive_start_month"]) ?>
<?php h::error( $form->errors["archive_start_day"]) ?>
</td>
</tr>
<tr class="template_setting pagination_template_setting">
<th>ページネーション設定</th>
<td colspan="3">
<span>１ページのアイテム数</span><input type="text" id="per_page" name="per_page"  class="input-mini" maxlength="10" value="<?php h::p( $form->per_page) ?>">
<?php h::error( $form->errors["per_page"]) ?>
</td>
</tr>
<tr class="template_setting pagination_template_setting archive_template_setting">
<th>出力ページ名設定</th>
<td colspan="3">
<span>プレフィックス</span><input type="text" id="archive_prefix" name="archive_prefix"  class="input-mini" maxlength="50" value="<?php h::p( $form->archive_prefix) ?>">
<span>サフィックス</span><input type="text" id="archive_suffix" name="archive_suffix"  class="input-mini" maxlength="50" value="<?php h::p( $form->archive_suffix) ?>"><br>
<?php h::error( $form->errors["archive_prefix"]) ?>
<?php h::error( $form->errors["archive_suffix"]) ?>
</td>
</tr>
<tr class="template_setting sub_template_setting">
<th>メインテンプレートID</th>
<td colspan="3">
<input type="text" id="main_template" name="main_template" class="input-mini" maxlength="50" value="<?php h::p( $form->main_template) ?>"><br>
<?php h::error( $form->errors["main_template"]) ?>
</td>
</tr>
<tr class="template_setting sub_template_setting">
<th>表示条件</th>
<td colspan="3">
<select id="cond" name="cond">
<option value="">--</option>
<?php foreach($cond_list as $cond_name): ?>
<option value="<?php h::p($cond_name) ?>" <?php h::select($form->cond, $cond_name) ?>><?php h::p($cond_name) ?></option>
<?php endforeach; ?>
</select>
<?php h::error( $form->errors["cond"]) ?>
</td>
</tr>
<tr class="template_setting">
<th>配信方式</th>
<td colspan="3">
<label class="radio"><input type="radio" id="output_method_static" name="output_method" value="static" <?php h::radio($form->output_method, 'static') ?> >静的</label>
<label class="radio"><input type="radio" id="output_method_dynamic" name="output_method" value="dynamic" <?php h::radio($form->output_method, 'dynamic') ?> >動的</label>
<?php h::error( $form->errors["output_method"]) ?>
</td>
</tr>
<tr class="template_setting">
<th>文字コード <span class="label label-important">※必須</span></th>
<td colspan="3">
<input type="text" id="char_code" name="char_code" maxlength="50" value="<?php h::p( $form->char_code) ?>"><br>
<?php h::error( $form->errors["char_code"]) ?>
</td>
</tr>
<tr class="template_setting">
<th>テンプレートID</th>
<td class="span3"><?php h::p($form->_id) ?></td>
<th>備考</th>
<td>
<input type="text" id="note" name="note" class="input-xlarge" maxlength="50" value="<?php h::p( $form->note) ?>">
<?php h::error( $form->errors["note"]) ?>
</td>
</tr>
<tr class="template_setting">
<th>操作</th>
<td colspan="3">
<?php if ($form->_id): ?>
<a href="#modal_delete" role="button" class="btn btn-small btn-danger" data-toggle="modal">テンプレート削除</a>
<div class="modal hide fade" id="modal_delete" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
<div class="modal-header">
<button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
<h3 id="myModalLabel">テンプレート削除確認</h3>
</div>
<div class="modal-body">
<p>テンプレートを削除しますか？</p>
</div>
<div class="modal-footer">
<button class="btn" data-dismiss="modal" aria-hidden="true">キャンセル</button>
<button class="btn btn-danger" onclick="me.template.deleteTemplate();return false;">削除する</button>
</div>
</div>
<?php endif; ?>
</td>
</tr>
</table>

<ul class="nav nav-tabs template_tab">
<li class="active"><a href="#" id="source_code_tab" onclick="me.template.selectSourceCode();" data-toggle="tab">ソースコード</a></li>
<li><a href="#" onclick="me.template.selectPreview();" data-toggle="tab">インスペクタ</a></li>
</ul>

<div class="row-fluid tag_handle">
<div class="span1"><span class="label tag_handle_label">MEタグ生成</span></div>
<div class="span7 tab_button">
<input type="button" class="btn btn-mini" value="テキスト" onclick="me.template.open('text');">
<input type="button" class="btn btn-mini" value="テキストエリア" onclick="me.template.open('textarea');">
<input type="button" class="btn btn-mini" value="プルダウンメニュー" onclick="me.template.open('select');">
<input type="button" class="btn btn-mini" value="スイッチ" onclick="me.template.open('switch');">
<input type="button" class="btn btn-mini" value="リスト" onclick="me.template.open('list');">
<input type="button" class="btn btn-mini" value="リッチテキスト" onclick="me.template.open('rich');">
<input type="button" class="btn btn-mini" value="日付" onclick="me.template.open('date');">
<input type="button" class="btn btn-mini" value="画像" onclick="me.template.open('img');">
<input type="button" class="btn btn-mini" value="ファイル" onclick="me.template.open('file');">
<input type="button" class="btn btn-mini" value="ソース" onclick="me.template.open('source');">
<input type="button" class="btn btn-mini" value="属性" onclick="me.template.open('attr');">
<input type="button" class="btn btn-mini" value="リピート" onclick="me.template.open('repeat');">
<input type="button" class="btn btn-mini" value="削除" onclick="me.template.open('delete');">
<input type="button" class="btn btn-mini" value="ディスプレイ" onclick="me.template.open('display');">
<input type="button" class="btn btn-mini" value="モジュール" onclick="me.template.open('module');">
<input type="button" class="btn btn-mini" value="インクルード" onclick="me.template.open('include');">
</div>
<div class="span4">
<div class="btn-group input-append">
<input type="text" id="query" class="input-medium" placeholder="検索">
<button id="search_prev" class="btn search_btn" data-search="prev" data-query="" title="前を検索"><i class="icon-chevron-up"></i></button>
<button id="search_next" class="btn search_btn" data-query=""><i class="icon-chevron-down" title="次を検索"></i></button>
<button class="btn" onclick="return me.template.clearSearch();" title="キャンセル">&times;</button>
<button class="btn dropdown-toggle" data-toggle="dropdown" title="検索オプション">
<span class="caret"></span>
</button>
<ul class="dropdown-menu pull-right">
<li class="search_dropdown">
<h5>MEタグ検索</h5>
<table>
<tbody>
<tr>
<td><input type="button" class="btn search_btn" value="MEタグ" data-query="/<!--{.*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="MEタグ（開始）" data-query="/<!--{[a-z].*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="MEタグ（終了）" data-query="/<!--{/.*?}-->/"></td>
<td></td>
<td></td>
</tr>
<tr>
<td><input type="button" class="btn search_btn" value="テキスト" data-query="/<!--{text .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="テキストエリア" data-query="/<!--{textarea .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="プルダウンメニュー" data-query="/<!--{select .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="スイッチ" data-query="/<!--{switch .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="リスト" data-query="/<!--{list .*?}-->/"></td>
</tr>
<tr>
<td><input type="button" class="btn search_btn" value="リッチテキスト" data-query="/<!--{rich .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="日付" data-query="/<!--{date .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="画像" data-query="/<!--{img .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="ファイル" data-query="/<!--{file .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="ソース" data-query="/<!--{source .*?}-->/"></td>
</tr>
<tr>
<td><input type="button" class="btn search_btn" value="属性" data-query="/<!--{attr .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="リピート" data-query="/<!--{repeat .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="削除" data-query="/<!--{delete .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="ディスプレイ" data-query="/<!--{display .*?}-->/"></td>
<td><input type="button" class="btn search_btn" value="モジュール" data-query="/<!--{module .*?}-->/"></td>
</tr>
<tr>
<td><input type="button" class="btn search_btn" value="インクルード" data-query="/<!--{include .*?}-->/"></td>
</tr>
</tbody>
</table>
</li>
<li class="divider"></li>
<li class="search_dropdown">
<h5>ショートカットキー</h5>
<p>エディターにフォーカスがある場合は次のショートカットキーを使用できます。</p>
<table class="table table-bordered table-striped">
<tbody>
<tr>
<th>検索ダイアログを開く</th>
<td>Ctrl-F / Cmd-F</td>
</tr>
<tr>
<th>次を検索</th>
<td>Ctrl-G / Cmd-G</td>
</tr>
<tr>
<th>前を検索</th>
<td>Shift-Ctrl-G / Shift-Cmd-G</td>
</tr>
<tr>
<th>置換</th>
<td>Shift-Ctrl-F / Cmd-Option-F</td>
</tr>
<tr>
<th>全て置換</th>
<td>Shift-Ctrl-R / Shift-Cmd-Option-F</td>
</tr>
<tr>
<th>継続検索ダイアログを開く<br>（検索後にダイアログが自動で閉じません）</th>
<td>Alt-F</td>
</tr>
<tr>
<th>指定行に移動</th>
<td>Alt-G</td>
</tr>
</tbody>
</table>
</li>
</ul>
</div>
<span id="search_result" class="search_result"></span>
</div>
</div>

<div id="code_editor" class="code_editor">
<textarea id="source_code" name="source_code" class="source_code" cols="50" rows="10"><?php h::p($form->source_code) ?></textarea>
</div>
<iframe id="preview_iframe" name="preview_iframe" class="preview_iframe hide" src="../Main/empty_page" onload="me.template.onloadIframe();"></iframe>

<div class="footer_action">
<div class="container">
<div id="page_action" class="page_action offset2">
<input type="button" id="back_link" class="btn" value="キャンセル" onclick="location.href='../Main/index?path=<?php h::p($form->page_path) ?>';return false;">
<input type="button" class="btn btn-primary" value="登録" onclick="me.template.submit();">
<label class="radio" title="テンプレートの登録のみを行う。"><input type="radio" id="option_no" name="ragister_option" value="" <?php h::radio($form->ragister_option, '') ?> >オプションなし</label>
<label class="radio" title="MEタグ内側のデータを初期値としてページを編集する。"><input type="radio" id="option_migrate" name="ragister_option" value="migrate" <?php h::radio($form->ragister_option, 'migrate') ?> >データ移行</label>
<label class="radio" title="関連するページを書き出す。"><input type="radio" id="option_write" name="ragister_option" value="write" <?php h::radio($form->ragister_option, 'write') ?> >ページ書き出し</label>
</div>
</div>
</div>

<input type="hidden" id="template_id" name="template_id" value="<?php h::p($form->_id) ?>">
<input type="hidden" id="_form_id" name="_form_id" value="<?php h::p($_form_id) ?>">
<input type="hidden" id="_token" name="_token" value="<?php h::get_token() ?>">
</form>
</body>
</html>